Inbox class

Inheritance

Constructors

Inbox({Key? key, String backendUrl = 'https://eu.api.novu.co', String socketUrl = 'https://eu.ws.novu.co', required String applicationIdentifier, String? subscriberId, Widget? icon, List<InboxTab> tabs = const [], Map<String, ContextValue>? context, Subscriber? subscriber, Widget renderBell(int unreadCount)?, Widget renderNotification(InboxNotification notification)?, Widget renderAvatar(InboxNotification notification)?, Widget renderSubject(InboxNotification notification)?, Widget renderBody(InboxNotification notification)?, dynamic onNotificationTap(InboxNotification notification)?, dynamic onPrimaryActionTap(InboxNotification notification)?, dynamic onSecondaryActionTap(InboxNotification notification)?})
const

Properties

applicationIdentifier String
final
backendUrl String
final
context Map<String, ContextValue>?
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onNotificationTap → dynamic Function(InboxNotification notification)?
final
onPrimaryActionTap → dynamic Function(InboxNotification notification)?
final
onSecondaryActionTap → dynamic Function(InboxNotification notification)?
final
renderAvatar Widget Function(InboxNotification notification)?
final
renderBell Widget Function(int unreadCount)?
final
renderBody Widget Function(InboxNotification notification)?
final
renderNotification Widget Function(InboxNotification notification)?
final
renderSubject Widget Function(InboxNotification notification)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socketUrl String
final
subscriber Subscriber?
final
subscriberId String?
final
tabs List<InboxTab>
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<Inbox>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited