NotificationTile class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- NotificationTile
Constructors
- NotificationTile({Key? key, required InboxNotification notification, dynamic onMarkAsRead(String notificationId)?, dynamic onMarkAsArchived(String notificationId)?, dynamic onMarkAsUnArchived(String notificationId)?, dynamic onTap(InboxNotification notification)?, Widget renderNotification(InboxNotification notification)?, Widget renderAvatar(InboxNotification notification)?, Widget renderSubject(InboxNotification notification)?, Widget renderBody(InboxNotification notification)?, dynamic onNotificationTap(InboxNotification notification)?, dynamic onPrimaryActionTap(InboxNotification notification)?, dynamic onSecondaryActionTap(InboxNotification notification)?})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- notification → InboxNotification
-
final
- onMarkAsArchived → dynamic Function(String notificationId)?
-
final
- onMarkAsRead → dynamic Function(String notificationId)?
-
final
- onMarkAsUnArchived → dynamic Function(String notificationId)?
-
final
- onNotificationTap → dynamic Function(InboxNotification notification)?
-
final
- onPrimaryActionTap → dynamic Function(InboxNotification notification)?
-
final
- onSecondaryActionTap → dynamic Function(InboxNotification notification)?
-
final
- onTap → dynamic Function(InboxNotification notification)?
-
final
- renderAvatar → Widget Function(InboxNotification notification)?
-
final
- renderBody → Widget Function(InboxNotification notification)?
-
final
- renderNotification → Widget Function(InboxNotification notification)?
-
final
- renderSubject → Widget Function(InboxNotification notification)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited