Subscriber class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
Subscriber({String? id, String? firstName, String? lastName, String? email, String? phone, String? avatar, String? locale, String? timezone, Map<
String, dynamic> ? data, required String subscriberId, bool? isOnline, DateTime? lastOnlineAt, String? organizationId, String? environmentId, bool? deleted, DateTime? createdAt, DateTime? updatedAt, String? v}) -
Subscriber.fromJson(Map<
String, dynamic> json) -
factory
Properties
- avatar → String?
-
final
-
channels
→ List<
Channel> -
Channels settings for subscriber
final
- createdAt → DateTime?
-
final
-
data
→ Map<
String, dynamic> ? -
final
- deleted → bool?
-
final
- email → String?
-
final
- environmentId → String?
-
final
- firstName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
The internal id novu generated for your subscriber, this is not the subscriberId matching your query.
final
- isOnline → bool?
-
final
- lastName → String?
-
final
- lastOnlineAt → DateTime?
-
final
- locale → String?
-
final
- organizationId → String?
-
final
- phone → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriberId ↔ String
-
The internal identifier you used to create this subscriber, usually correlates to the id the user in your systems
latefinal
- timezone → String?
-
final
-
topics
→ List<
String> -
Topics that subscriber belongs to
final
- updatedAt → DateTime?
-
final
- v → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited